@@ -92,7 +92,7 @@ def run_api(id, key):
 
     update_directories_api(NAME, PURGE_DIRECTORIES_DAYS)
 
-    if check_too_old(JSON_PATH_STATIONS, STATIONS_MAX_FILE_AGE):
+    if check_too_old(JSON_PATH_STATIONS, STATIONS_MAX_FILE_AGE*2):
         page = 0
         params = dict()
         stations = dict()
@@ -119,7 +119,7 @@ def run_api(id, key):
     else:
         debug.log('Station file not old enough')
 
-    if check_too_old(XML_TEMP_PATH_FLIGHTS, FLIGHTS_MAX_FILE_AGE):
+    if check_too_old(XML_TEMP_PATH_FLIGHTS, FLIGHTS_MAX_FILE_AGE*2):
         page = 0
         params = {
             'sort': '+scheduleDateTime',
