@@ -1,6 +1,7 @@
 import xml.etree.ElementTree as ET
 import os
 import glob
+import unidecode
 
 from firstimpression.constants import APIS, TEMP_FOLDER, LOCAL_INTEGRATED_FOLDER, PICTURE_FORMATS, TAGS_TO_REMOVE, REPLACE_DICT
 from firstimpression.file import update_directories_api, create_directories, check_too_old, write_root_to_xml_files, list_files_dir, download_media, xml_to_root
@@ -9,6 +10,7 @@ from firstimpression.text import remove_tags_from_string
 from firstimpression.xml import get_attrib_from_element
 from firstimpression.scala import variables, Log, install_content
 
+from w3lib.html import replace_entities
 ##################################################################################################
 # LOGGING
 ##################################################################################################
@@ -115,7 +117,7 @@ def check_api(news_categories):
             file_path = file_path[0]
             debug.log('glob filepath: {}'.format(file_path))
 
-            if check_too_old(file_path, MAX_FILE_AGE):
+            if check_too_old(file_path, MAX_FILE_AGE*2):
                 svars['skipscript'] = True
                 info.log('file too old')
                 break
@@ -161,11 +163,11 @@ def install_picture_content_wrap(picture_format, subdirectory, temp_folder, elem
 
 
 def get_title(news_item):
-    return news_item.findtext(TAGS['title'], '')
+    return unidecode.unidecode(replace_entities(news_item.findtext(TAGS['title'], '')))
 
 
 def get_description(news_item):
-    return remove_tags_from_string(TAGS_TO_REMOVE, news_item.findtext(TAGS['description'], ''))
+    return unidecode.unidecode(replace_entities(remove_tags_from_string(TAGS_TO_REMOVE, news_item.findtext(TAGS['description'], ''))))
 
 ##################################################################################################
 # PARSE FUNCTIONS
