@@ -132,7 +132,7 @@ def check_api(news_categories):
                 file_found = True
                 file_path = os.path.join(LOCAL_PATH, file)
                 debug.log('file path: {}'.format(file_path))
-                if check_too_old(file_path, MAX_FILE_AGE):
+                if check_too_old(file_path, MAX_FILE_AGE*2):
                     svars['skipscript'] = True
                     info.log('file too old')
                     break
