@@ -117,7 +117,7 @@ def check_api():
         file_path_longest = file_path_longest[0]
         debug.log('glob filepath: {}'.format(file_path_longest))
 
-        if check_too_old(file_path_longest, MAX_FILE_AGE):
+        if check_too_old(file_path_longest, MAX_FILE_AGE*2):
             skip = True
             info.log('file {} too old'.format(file_path_longest))
         else:
@@ -133,7 +133,7 @@ def check_api():
         file_path_closest = file_path_closest[0]
         debug.log('glob filepath: {}'.format(file_path_closest))
 
-        if check_too_old(file_path_closest, MAX_FILE_AGE):
+        if check_too_old(file_path_closest, MAX_FILE_AGE*2):
             skip = True
             info.log('file {} too old'.format(file_path_closest))
         else:
