@@ -476,12 +476,14 @@ class Log:
         try:
             svars = variables()
             self.debug = svars['Player.debug_python']
-        except KeyError:
+        except Exception:
             self.debug = False
-    
     def log(self, msg):
-        svars = variables()
-        self.debug = svars['Player.debug_python']
+        try:
+            svars = variables()
+            self.debug = svars['Player.debug_python']
+        except Exception:
+            self.debug = False
         if (self.level == NAMELEVEL['DEBUG'] and self.debug) or not self.level == NAMELEVEL['DEBUG']:
             log(self.level, '{}: {}'.format(self.script, msg))
     
